:mod:`traits.traits` Module
===========================

.. automodule:: traits.traits
    :no-members:

.. currentmodule:: traits.traits

Classes
-------

.. autoclass:: Default

.. autoclass:: Property

.. autoclass:: ForwardProperty

.. autoclass:: Color

.. autoclass:: RGBColor

.. autoclass:: Font

Functions
---------

.. autofunction:: Trait


Private Classes
---------------

.. autoclass:: traits.traits._InstanceArgs

.. autoclass:: traits.traits._TraitMaker
